==> pre-json-1.0.6.tgz: package/index.js <==

class Transformer {

    constructor( transformers ) {
        
        this.transformers = [

            ... transformers,

            { test : (x) => x === null },
            { test : (x) => typeof x === "number" },
            { test : (x) => typeof x === "string" },
            { test : (x) => typeof x === "boolean" },

            {
                test   : (x) => Array.isArray( x ),
                encode : (x,e) => x.map( e ),
                decode : (x,d) => x.map( d )
            },

            {
                test   : (x) => typeof x === "object",
                encode : (x,e) => { var r = {}; Object.keys( x ).forEach( k => r[ k ] = e( x[ k ] ) ); return r; },
                decode : (x,d) => { var r = {}; Object.keys( x ).forEach( k => r[ k ] = d( x[ k ] ) ); return r; }
            },


        ];

    }

    encode( data, rasterize = false ) {

        for( var ix = 0; ix < this.transformers.length; ix += 1 ) {

            var transformer = this.transformers[ ix ];
            
            if( !transformer.test( data ) )
                continue;

            var val = transformer.encode ? transformer.encode( data, (e) => this.encode( e, rasterize ) ) : data;

            return rasterize ? val : { pre_id : ix, val };

        }

        throw new Error( "No transformer found" );

    }

    decode( data ) {

        var transformer = this.transformers[ data.pre_id ];

        if( transformer === undefined )
            throw new Error( "No transformer found." );

        return transformer.decode ? transformer.decode( data.val, this.decode.bind( this ) ) : data.val;

    }

}

module.exports = Transformer;

==> pre-json-1.0.7.tgz: package/index.js <==

class Transformer {

    constructor( transformers ) {
        
        this.transformers = [

            ... transformers,

            { test : (x) => x === null },
            { test : (x) => typeof x === "number" },
            { test : (x) => typeof x === "string" },
            { test : (x) => typeof x === "boolean" },

            {
                test   : (x) => Array.isArray( x ),
                encode : (x,e) => x.filter( x => x !== undefined ).map( e ),
                decode : (x,d) => x.map( d )
            },

            {
                test   : (x) => typeof x === "object",

                encode : function( data, encoder ) {
                    var results = {};
                    for( var key of Object.keys( data ) ) {
                        if( data[ key ] === undefined )
                            continue;
                        results[ key ] = encoder( data[ key ] );
                    }
                    return results;
                },

                decode : function( data, decoder ) {
                    var results = {};
                    for( var key of Object.keys( data ) )
                        results[ key ] = decoder( data[ key ] );
                    return results;
                },

            },


        ];

    }

    encode( data, rasterize = false ) {

        for( var ix = 0; ix < this.transformers.length; ix += 1 ) {

            var transformer = this.transformers[ ix ];
            
            if( !transformer.test( data ) )
                continue;

            var val = transformer.encode ? transformer.encode( data, (e) => this.encode( e, rasterize ) ) : data;

            return rasterize ? val : { pre_id : ix, val };

        }

        throw new Error( "No transformer found" );

    }

    decode( data ) {

        var transformer = this.transformers[ data.pre_id ];

        if( transformer === undefined )
            throw new Error( "No transformer found." );

        return transformer.decode ? transformer.decode( data.val, this.decode.bind( this ) ) : data.val;

    }

}

module.exports = Transformer;
